package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.ResourceMetricsInfo;

/**
 * 资源指标信息Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface ResourceMetricsInfoMapper 
{
    /**
     * 查询资源指标信息
     * 
     * @param id 资源指标信息主键
     * @return 资源指标信息
     */
    public ResourceMetricsInfo selectResourceMetricsInfoById(Integer id);

    /**
     * 查询资源指标信息列表
     * 
     * @param resourceMetricsInfo 资源指标信息
     * @return 资源指标信息集合
     */
    public List<ResourceMetricsInfo> selectResourceMetricsInfoList(ResourceMetricsInfo resourceMetricsInfo);

    /**
     * 新增资源指标信息
     * 
     * @param resourceMetricsInfo 资源指标信息
     * @return 结果
     */
    public int insertResourceMetricsInfo(ResourceMetricsInfo resourceMetricsInfo);

    /**
     * 修改资源指标信息
     * 
     * @param resourceMetricsInfo 资源指标信息
     * @return 结果
     */
    public int updateResourceMetricsInfo(ResourceMetricsInfo resourceMetricsInfo);

    /**
     * 删除资源指标信息
     * 
     * @param id 资源指标信息主键
     * @return 结果
     */
    public int deleteResourceMetricsInfoById(Integer id);

    /**
     * 批量删除资源指标信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteResourceMetricsInfoByIds(Integer[] ids);
}
